# dashboard
Dashboard to explore 3DB experiments

## Install

`pip install threedboard`

## Run the dasboard

`python -m threedboard EXPERIMENT_FOLDER`

## Build from source

When cloning the repo directory the source code for the website has to be built. You will require `node` and `npm` and then run:

`python setup.py build_dashboard`

**Note:** This is not necessary if you install via `pip` it ships with everything built for you out of the box. No external dependencies required to run the dashboard.
